@@ -1,3 +1,7 @@
+# Copyright (c) 2017 pandas-gbq Authors All rights reserved.
+# Use of this source code is governed by a BSD-style
+# license that can be found in the LICENSE file.
+
 """Private module for fetching Google BigQuery credentials."""
 
 import logging
@@ -19,9 +23,7 @@ SCOPES = ["https://www.googleapis.com/auth/bigquery"]
 # machine.
 #
 # See: https://cloud.google.com/docs/authentication/end-user for details.
-CLIENT_ID = (
-    "725825577420-unm2gnkiprugilg743tkbig250f4sfsj.apps.googleusercontent.com"
-)
+CLIENT_ID = "725825577420-unm2gnkiprugilg743tkbig250f4sfsj.apps.googleusercontent.com"
 CLIENT_SECRET = "4hqze9yI8fxShls8eJWkeMdJ"
 
 
@@ -51,15 +53,12 @@ method from the google-auth package."""
     return credentials, project_id
 
 
-def get_credentials_cache(
-    reauth,
-):
+def get_credentials_cache(reauth):
     import pydata_google_auth.cache
 
     if reauth:
         return pydata_google_auth.cache.WriteOnlyCredentialsCache(
-            dirname=CREDENTIALS_CACHE_DIRNAME,
-            filename=CREDENTIALS_CACHE_FILENAME,
+            dirname=CREDENTIALS_CACHE_DIRNAME, filename=CREDENTIALS_CACHE_FILENAME,
         )
     return pydata_google_auth.cache.ReadWriteCredentialsCache(
         dirname=CREDENTIALS_CACHE_DIRNAME, filename=CREDENTIALS_CACHE_FILENAME
