@@ -9,6 +9,36 @@ from unittest import mock
 import pytest
 
 
+def mock_get_credentials(*args, **kwargs):
+    import google.auth.credentials
+
+    mock_credentials = mock.create_autospec(google.auth.credentials.Credentials)
+    return mock_credentials, "default-project"
+
+
+@pytest.fixture
+def mock_service_account_credentials():
+    import google.oauth2.service_account
+
+    mock_credentials = mock.create_autospec(google.oauth2.service_account.Credentials)
+    return mock_credentials
+
+
+@pytest.fixture
+def mock_compute_engine_credentials():
+    import google.auth.compute_engine
+
+    mock_credentials = mock.create_autospec(google.auth.compute_engine.Credentials)
+    return mock_credentials
+
+
+@pytest.fixture(autouse=True)
+def no_auth(monkeypatch):
+    import pydata_google_auth
+
+    monkeypatch.setattr(pydata_google_auth, "default", mock_get_credentials)
+
+
 @pytest.fixture(autouse=True, scope="function")
 def reset_context():
     import pandas_gbq
@@ -20,24 +50,12 @@ def reset_context():
 @pytest.fixture(autouse=True)
 def mock_bigquery_client(monkeypatch):
     import google.cloud.bigquery
-    import google.cloud.bigquery.table
 
     mock_client = mock.create_autospec(google.cloud.bigquery.Client)
     # Constructor returns the mock itself, so this mock can be treated as the
     # constructor or the instance.
     mock_client.return_value = mock_client
-    mock_schema = [google.cloud.bigquery.SchemaField("_f0", "INTEGER")]
-    # Mock out SELECT 1 query results.
-    mock_query = mock.create_autospec(google.cloud.bigquery.QueryJob)
-    mock_query.job_id = "some-random-id"
-    mock_query.state = "DONE"
-    mock_rows = mock.create_autospec(google.cloud.bigquery.table.RowIterator)
-    mock_rows.total_rows = 1
-    mock_rows.schema = mock_schema
-    mock_rows.__iter__.return_value = [(1,)]
-    mock_query.result.return_value = mock_rows
-    mock_client.query.return_value = mock_query
-    # Mock table creation.
     monkeypatch.setattr(google.cloud.bigquery, "Client", mock_client)
     mock_client.reset_mock()
+
     return mock_client
